#ifndef OUTPUTWIN_H
#define OUTPUTWIN_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <qwidget.h>
#include <qmlined.h>
#include <qpushbt.h>
#include <qchkbox.h>
#include <qfile.h>
#include <stdio.h>
#include <stdarg.h>

#include "log.h"
#include "mledit.h"

//=====OutputWin===================================================================================
class OutputWin : public QWidget, public COutputWindow
{
public:
   OutputWin (QWidget *parent = 0, const char *name = 0);
   virtual void wprintf(const char *formatIn, va_list argp);
protected:
   void resizeEvent (QResizeEvent *);   
   MLEditWrap *outputBox;
   QPushButton *btnHide, *btnClear;
};


#endif
